@@ -15,8 +15,13 @@ from cdd.ast_utils import (
     merge_modules,
     set_value,
 )
-from cdd.pure_utils import INIT_FILENAME, no_magic_dir2attr, rpartial
-from cdd.tests.mocks import imports_header
+from cdd.pure_utils import (
+    INIT_FILENAME,
+    no_magic_dir2attr,
+    rpartial,
+    sanitise_emit_name,
+)
+from cdd.tests.mocks import imports_header_ast
 
 
 def get_module_contents(obj, module_root_dir, current_module=None, _result={}):
@@ -35,7 +40,7 @@ def get_module_contents(obj, module_root_dir, current_module=None, _result={}):
     :param _result: The result var (used internally as accumulator)
     :type _result: ```dict```
 
-    :returns: Values (could be modules, classes, and whatever other symbols are exposed)
+    :return: Values (could be modules, classes, and whatever other symbols are exposed)
     :rtype: ```Generator[Any]```
     """
     for name, symbol in no_magic_dir2attr(obj).items():
@@ -65,8 +70,10 @@ def emit_file_on_hierarchy(
     emit_name,
     module_name,
     new_module_name,
+    mock_imports,
     filesystem_layout,
     output_directory,
+    no_word_wrap,
     dry_run,
 ):
     """
@@ -84,28 +91,35 @@ def emit_file_on_hierarchy(
     :param new_module_name: Name of [new] module
     :type new_module_name: ```str```
 
+    :param mock_imports: Whether to generate mock TensorFlow imports
+    :type mock_imports: ```bool```
+
     :param filesystem_layout: Hierarchy of folder and file names generated. "java" is file per package per name.
     :type filesystem_layout: ```Literal["java", "as_input"]```
 
     :param output_directory: Where to place the generated exposed interfaces to the given `--module`.
     :type output_directory: ```str```
 
+    :param no_word_wrap: Whether word-wrap is disabled (on emission).
+    :type no_word_wrap: ```Optional[Literal[True]]```
+
     :param dry_run: Show what would be created; don't actually write to the filesystem
     :type dry_run: ```bool```
 
-    :returns: Import to generated module
+    :return: Import to generated module
     :rtype: ```ImportFrom```
     """
     mod_name, _, name = name_orig_ir[0].rpartition(".")
     original_relative_filename_path, ir = name_orig_ir[1], name_orig_ir[2]
     assert original_relative_filename_path
-    if not name:
-        name = ir["name"]
+    if not name and ir.get("name") is not None:
+        name = ir.get("name")
     mod_path = path.join(
         output_directory,
         new_module_name,
         mod_name.replace(".", path.sep),
     )
+    # print("mkdir\t{mod_path!r}".format(mod_path=mod_path))
     if not path.isdir(mod_path):
         if dry_run:
             print("mkdir\t{mod_path!r}".format(mod_path=mod_path))
@@ -164,7 +178,7 @@ def emit_file_on_hierarchy(
                 )
             ) if dry_run else makedirs(emit_filename_dir)
 
-    if not symbol_in_file:
+    if not symbol_in_file and (ir.get("name") or ir["params"] or ir["returns"]):
         _emit_symbol(
             name_orig_ir,
             emit_name,
@@ -175,6 +189,8 @@ def emit_file_on_hierarchy(
             ir,
             isfile_emit_filename,
             name,
+            mock_imports,
+            no_word_wrap,
             dry_run,
         )
 
@@ -207,6 +223,8 @@ def _emit_symbol(
     intermediate_repr,
     isfile_emit_filename,
     name,
+    mock_imports,
+    no_word_wrap,
     dry_run,
 ):
     """
@@ -245,16 +263,21 @@ def _emit_symbol(
     :param name: Name of the node being generated
     :type name: ```str```
 
+    :param mock_imports: Whether to generate mock TensorFlow imports
+    :type mock_imports: ```bool```
+
+    :param no_word_wrap: Whether word-wrap is disabled (on emission).
+    :type no_word_wrap: ```Optional[Literal[True]]```
+
     :param dry_run: Show what would be created; don't actually write to the filesystem
     :type dry_run: ```bool```
 
-    :returns: Import to generated module
+    :return: Import to generated module
     :rtype: ```ImportFrom```
     """
-    gen_node = getattr(
-        emit, {"argparse": "argparse_function", "class": "class_"}[emit_name]
-    )(
+    gen_node = getattr(emit, sanitise_emit_name(emit_name))(
         intermediate_repr,
+        word_wrap=no_word_wrap is None,
         **dict(
             **{
                 "{emit_name}_name".format(
@@ -290,7 +313,7 @@ def _emit_symbol(
                                 )
                             ),
                         ),
-                        ast.parse(imports_header).body,
+                        imports_header_ast if mock_imports else iter(()),
                         (gen_node, __all___node),
                     )
                 )
