@@ -3,6 +3,7 @@ Mocks for methods
 """
 
 from ast import (
+    Assign,
     Attribute,
     BinOp,
     Call,
@@ -16,10 +17,12 @@ from ast import (
     Name,
     Pass,
     Return,
+    Store,
     Subscript,
     Tuple,
     arguments,
     fix_missing_locations,
+    keyword,
 )
 from functools import partial
 from operator import add
@@ -29,6 +32,8 @@ from cdd.ast_utils import maybe_type_comment, set_arg, set_slice, set_value
 from cdd.pure_utils import emit_separating_tabs, tab
 from cdd.tests.mocks.docstrings import (
     docstring_google_tf_adadelta,
+    docstring_google_tf_mean_squared_error_str,
+    docstring_google_tf_ops_losses__safe_mean_str,
     docstring_header_str,
     docstring_no_default_doc_wrapped_str,
     docstring_no_type_no_default_str,
@@ -86,7 +91,7 @@ class C(object):
         :param data_loader_kwargs: pass this as arguments to data_loader function
         :type data_loader_kwargs: ```Optional[dict]```
 {sep}
-        :returns: Train and tests dataset splits.
+        :return: Train and tests dataset splits.
         :rtype: ```Union[Tuple[tf.data.Dataset, tf.data.Dataset], Tuple[np.ndarray,
 {indent}np.ndarray]]```
         """
@@ -121,7 +126,7 @@ class C(object):
 
         :param data_loader_kwargs: pass this as arguments to data_loader function
 
-        :returns: Train and tests dataset splits.
+        :return: Train and tests dataset splits.
         """
         return np.empty(0), np.empty(0)
 '''.format(
@@ -153,7 +158,7 @@ class C(object):
 
         :param data_loader_kwargs: pass this as arguments to data_loader function
 
-        :returns: Train and tests dataset splits.
+        :return: Train and tests dataset splits.
         """
         # some comment
         print(5 * 5)
@@ -181,7 +186,7 @@ class C(object):
 
         :param K: backend engine, e.g., `np` or `tf`.
 
-        :returns: Train and tests dataset splits.
+        :return: Train and tests dataset splits.
         """
         return np.empty(0), np.empty(0)
 '''.format(
@@ -610,7 +615,7 @@ def add_6_5(*, a=6, b=5):
     :param b: second param
     :type b: ```int```
 
-    :returns: Aggregated summation of `a` and `b`.
+    :return: Aggregated summation of `a` and `b`.
     :rtype: ```int```
     """
     return operator.add(a, b)
@@ -635,7 +640,7 @@ function_adder_ast = FunctionDef(
                 ":type a: ```int```\n\n    "
                 ":param b: second param\n    "
                 ":type b: ```int```\n\n    "
-                ":returns: Aggregated summation of `a` and `b`.\n    "
+                ":return: Aggregated summation of `a` and `b`.\n    "
                 ":rtype: ```int```\n    ",
             )
         ),
@@ -718,7 +723,7 @@ def call_cliff(
 
     :param **kwargs: additional keyword arguments
 
-    :returns: backend engine
+    :return: backend engine
     """
     return K
 '''
@@ -762,6 +767,7 @@ method_complex_args_variety_ast = FunctionDef(
         kwarg=set_arg("kwargs"),
         defaults=[],
         arg=None,
+        vararg=None,
     ),
     body=[
         Expr(
@@ -773,7 +779,7 @@ method_complex_args_variety_ast = FunctionDef(
                 ":param tfds_dir: directory to look for models in.\n\n    "
                 ":param writer: IO object to write out to\n\n    "
                 ":param **kwargs: additional keyword arguments\n\n    "
-                ":returns: backend engine\n    ",
+                ":return: backend engine\n    ",
             )
         ),
         Return(value=Name("K", Load()), expr=None),
@@ -833,14 +839,112 @@ function_google_tf_squared_hinge_docstring_str = "\n".join(
 function_google_tf_squared_hinge = (
     "def squared_hinge(y_true, y_pred):",
     '  """{}"""'.format(function_google_tf_squared_hinge_docstring_str),
-    "  y_pred = ops.convert_to_tensor_v2(y_pred)",
-    "  y_true = math_ops.cast(y_true, y_pred.dtype)",
-    "  y_true = _maybe_convert_labels(y_true)",
-    "  return K.mean(",
-    "      math_ops.square(math_ops.maximum(1. - y_true * y_pred, 0.)), axis=-1)",
+    "  "
+    + "\n  ".join(
+        (
+            "y_pred = ops.convert_to_tensor_v2(y_pred)",
+            "y_true = math_ops.cast(y_true, y_pred.dtype)",
+            "y_true = _maybe_convert_labels(y_true)",
+            "return K.mean(",
+            "    math_ops.square(math_ops.maximum(1. - y_true * y_pred, 0.)), axis=-1)",
+        )
+    ),
 )
+
 function_google_tf_squared_hinge_str = "\n".join(function_google_tf_squared_hinge)
 
+# `from tensorflow.python.ops.losses.losses_impl import _safe_mean` @ tf-nightly:2.7.0.dev20210908
+function_google_tf_ops_losses__safe_mean_ast = FunctionDef(
+    name="_safe_mean",
+    args=arguments(
+        args=list(map(set_arg, ("losses", "num_present"))),
+        arg=None,
+        defaults=[],
+        kw_defaults=[],
+        kwarg=None,
+        kwonlyargs=[],
+        posonlyargs=[],
+        vararg=None,
+    ),
+    body=[
+        Expr(value=set_value(docstring_google_tf_ops_losses__safe_mean_str)),
+        Assign(
+            targets=[Name(id="total_loss", ctx=Store())],
+            value=Call(
+                func=Attribute(
+                    value=Name(id="math_ops", ctx=Load()), attr="reduce_sum", ctx=Load()
+                ),
+                args=[Name(id="losses", ctx=Load())],
+                keywords=[],
+            ),
+            **maybe_type_comment
+        ),
+        Return(
+            value=Call(
+                func=Attribute(
+                    value=Name(id="math_ops", ctx=Load()), attr="div_no_nan", ctx=Load()
+                ),
+                args=[
+                    Name(id="total_loss", ctx=Load()),
+                    Name(id="num_present", ctx=Load()),
+                ],
+                keywords=[keyword(arg="name", value=set_value("value"))],
+            )
+        ),
+    ],
+    decorator_list=[],
+)
+
+# ```python
+# import ast
+# import inspect
+# from tensorflow.python.ops.losses.losses_impl import mean_squared_error
+#
+# print(ast.dump(ast.parse(inspect.getsource(mean_squared_error)).body[0], indent=4)
+# ```
+# https://github.com/tensorflow/tensorflow/blob/v2.7.0/tensorflow/python/ops/losses/losses_impl.py#L624-L771
+#
+# minus non-docstring body and `decorator_list`
+function_google_tf_mean_squared_error_ast = FunctionDef(
+    name="mean_squared_error",
+    args=arguments(
+        posonlyargs=[],
+        args=list(
+            map(
+                set_arg,
+                (
+                    "labels",
+                    "predictions",
+                    "weights",
+                    "scope",
+                    "loss_collection",
+                    "reduction",
+                ),
+            )
+        ),
+        kwonlyargs=[],
+        kw_defaults=[],
+        defaults=[
+            set_value(1.0),
+            set_value(None),
+            Attribute(
+                value=Attribute(
+                    value=Name(id="ops", ctx=Load()), attr="GraphKeys", ctx=Load()
+                ),
+                attr="LOSSES",
+                ctx=Load(),
+            ),
+            Attribute(
+                value=Name(id="Reduction", ctx=Load()),
+                attr="SUM_BY_NONZERO_WEIGHTS",
+                ctx=Load(),
+            ),
+        ],
+    ),
+    body=[Expr(value=set_value(docstring_google_tf_mean_squared_error_str))],
+    decorator_list=[],
+)
+
 docstring_google_tf_adadelta_function = (
     "",
     "class Adadelta(object):",
@@ -949,6 +1053,8 @@ __all__ = [
     "function_adder_str",
     "function_default_complex_default_arg_ast",
     "function_default_complex_default_arg_str",
+    "function_google_tf_mean_squared_error_ast",
+    "function_google_tf_ops_losses__safe_mean_ast",
     "function_google_tf_squared_hinge_str",
     "method_complex_args_variety_ast",
     "method_complex_args_variety_str",
