@@ -1,9 +1,11 @@
 """ Tests for gen_routes subcommand """
+
 import ast
 from ast import FunctionDef
 from binascii import crc32
 from itertools import tee
 from os import path, remove
+from os.path import extsep
 from tempfile import TemporaryDirectory
 from unittest import TestCase
 
@@ -40,12 +42,12 @@ def populate_files(tempdir, init_with_crud):
                      Literal['D', 'C', 'R'], Literal['D', 'C', 'U'], Literal['D', 'R', 'C'],
                      Literal['D', 'R', 'U'], Literal['D', 'U', 'C'], Literal['D', 'U', 'R']]```
 
-    :returns: model_path, routes_path
+    :return: model_path, routes_path
     :rtype: ```Tuple[str, str]```
     """
-    model_path = path.join(tempdir, "model.py")
-    routes_path = path.join(tempdir, "routes.py")
-    open(path.join(tempdir, "__init__.py"), "a").close()
+    model_path = path.join(tempdir, "model{extsep}py".format(extsep=extsep))
+    routes_path = path.join(tempdir, "routes{extsep}py".format(extsep=extsep))
+    open(path.join(tempdir, "__init__{extsep}py".format(extsep=extsep)), "a").close()
 
     model = "\n".join(
         (
@@ -77,7 +79,7 @@ def populate_files(tempdir, init_with_crud):
 
 
 class TestGenRoutes(TestCase):
-    """ Test class for gen_routes.py """
+    """Test class for gen_routes.py"""
 
     def further_tests(self, mod):
         """
@@ -97,7 +99,7 @@ class TestGenRoutes(TestCase):
         )
 
     def test_gen_routes_no_change(self) -> None:
-        """ Tests `gen_routes` when routes are identical in app name, route path and method """
+        """Tests `gen_routes` when routes are identical in app name, route path and method"""
 
         self.gen_routes_tester(
             approach="update",
@@ -108,7 +110,7 @@ class TestGenRoutes(TestCase):
         )
 
     def test_gen_routes_update(self) -> None:
-        """ Tests `gen_routes` when routes do exists """
+        """Tests `gen_routes` when routes do exists"""
 
         self.gen_routes_tester(
             approach="update",
@@ -119,7 +121,7 @@ class TestGenRoutes(TestCase):
         )
 
     def test_gen_routes_update_missing(self) -> None:
-        """ Tests `gen_routes` when routes do exists, but `destroy` route (DELETE method) is missing """
+        """Tests `gen_routes` when routes do exists, but `destroy` route (DELETE method) is missing"""
 
         self.gen_routes_tester(
             approach="update",
@@ -130,7 +132,7 @@ class TestGenRoutes(TestCase):
         )
 
     def test_gen_routes_insert(self) -> None:
-        """ Tests `gen_routes` when routes do not exist """
+        """Tests `gen_routes` when routes do not exist"""
 
         def _further_tests(mod):
             """
